import { Observable } from 'rxjs';
import { AlertInterface } from '../interfaces/alert.interface';
import { Alert } from '../models/alert.model';
import * as i0 from "@angular/core";
/**
 * The `AlertService` provides convenience methods for emitting alert messages
 * of type error, info, success, and warn.
 */
export declare class AlertService {
    /** List of alerts that should be rendered on screen. */
    private alerts;
    /** Subject used to emit latest list of alerts. */
    private alertsSubject;
    /** Observable of list of alerts. */
    alerts$: Observable<Alert[]>;
    /** Subject used to emit latest alert added to array of alerts. */
    private subject;
    /** Default id to set for alerts. */
    private defaultId;
    /**
     * An observable for alerts that can be subscribed to for rendering or
     * dealing with alerts.
     *
     * @param id Optional id value to filter on.
     * @returns An observable for alert messages.
     */
    onAlert(id?: string): Observable<Alert>;
    /**
     * Emits the given message as an error alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    error(message: string, options?: AlertInterface): void;
    /**
     * Emits the given message as an info alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    info(message: string, options?: AlertInterface): void;
    /**
     * Emits the given message as a success alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    success(message: string, options?: AlertInterface): void;
    /**
     * Emits the given message as a warning alert.
     *
     * @param message The message to render in the alert.
     * @param options Optional options to include for alert.
     */
    warn(message: string, options?: AlertInterface): void;
    /**
     * Emits the given alert. You should not need to call this method directly
     * unless you define alerts other than error, info, success, or warn.
     * Leaving this public so that is available as an option though...
     *
     * @param alert The alert to render.
     */
    alert(alert: Alert): void;
    /**
     * Clears alerts by emitting an Alert with empty message. AlertComponent has
     * logic to clear alerts when next Alert has empty message.
     *
     * @param id Optional id to set for the alert.
     */
    clear(id?: string): void;
    /**
     * Removes the given alert from array of alerts (if it is still in array).
     *
     * @param alert The alert to remove;
     */
    removeAlert(alert: Alert): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AlertService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AlertService>;
}
