/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { AfterViewChecked, ChangeDetectorRef, ElementRef, QueryList } from '@angular/core';
import { JsonModel } from '@ngx-material-dashboard/base-json';
import { CollectionComponent } from '../../../collection/components/collection/collection.component';
import { SelectionService } from '../../../collection/services/selection.service';
import { ScreenSizeService } from '../../../layout/services/screen-size.service';
import { SorterComponent } from '../../../toolbar/pages/sorter/sorter.component';
import * as i0 from "@angular/core";
/**
 * The `Grid` extends `Collection`, and is meant for rendering items in a grid
 * layout. The component dynamically calculates the width of each item in the
 * grid and determines how many items to display in each row based on the space
 * available. You must define the template for each item in the grid in the
 * template where you intend to include this component. A `Sorter` is rendered
 * above the data grid, which is meant to allow users to well sort the data in
 * the grid based on the provided `field` options users should be able to sort
 * the data on.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-grid [data]="data" [fields]="fields">
 *     <ng-template #model let-model="model">
 *        <mat-card>
 *            <mat-card-title>
 *                {{model.id}} Title
 *            </mat-card-title>
 *            <mat-card-content>
 *                Content for dummy object {{model.id}}
 *            </mat-card-content>
 *       </mat-card>
 *     </ng-template>
 * </ngx-mat-grid>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-grid-usage-example',
 *     templateUrl: './basic-grid-usage-example.html'
 * }) export class BasicGridUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 * }
 * ```
 */
export declare class GridComponent<T extends JsonModel> extends CollectionComponent<T> implements AfterViewChecked {
    private screenSizeService;
    private changeDetectorRef;
    /** A reference to the grid list in the component. */
    grid: ElementRef;
    sort$?: SorterComponent;
    /** A reference to the grid tiles in the component. */
    tiles: QueryList<ElementRef>;
    /** The number of columns to render in the grid. */
    cols: number;
    constructor(screenSizeService: ScreenSizeService, changeDetectorRef: ChangeDetectorRef, selectionService: SelectionService<T>);
    ngAfterViewChecked(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<GridComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GridComponent<any>, "ngx-mat-grid", never, {}, {}, never, never>;
}
