import { JsonModel } from '@ngx-material-dashboard/base-json';
import { PagedCollectionComponent } from '../../../collection/components/paged-collection/paged-collection.component';
import * as i0 from "@angular/core";
/**
 * The `PagedGrid` is a wrapper for the `Grid` component which adds paging
 * capabilities. Like the `Grid`, you must define the template for each item in
 * the grid in the template where you intend to include this component.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-grid [data]="tasks" class="marker-paged-grid">
 *     <ng-template #model let-model="model">
 *         <mat-card>
 *             <mat-card-title>
 *                 {{model.id}} Title
 *             </mat-card-title>
 *             <mat-card-content>
 *                 Content for dummy object {{model.id}}
 *             </mat-card-content>
 *         </mat-card>
 *     </ng-template>
 * </ngx-mat-paged-grid>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {Task} from './tasks'; // this should extend JsonModel
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * }) UsingBasicUsageExample {
 *     tasks: Task[] = [...];
 * }
 * ```
 */
export declare class PagedGridComponent<T extends JsonModel> extends PagedCollectionComponent<T> {
    static ɵfac: i0.ɵɵFactoryDeclaration<PagedGridComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PagedGridComponent<any>, "ngx-mat-paged-grid", never, {}, {}, never, never>;
}
