import { JsonModel } from '@ngx-material-dashboard/base-json';
import { PagedCollectionComponent } from '../../../collection/components/paged-collection/paged-collection.component';
import * as i0 from "@angular/core";
/**
 * The `PagedList` is a wrapper for the `List`, and renders items in a list
 * with built in paging capabilities. You must provide the template for each
 * item to render in the list. A `MatPaginator` is rendered below the `Sorter`
 * and data list to provide paging capabilities for the data.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-paged-list [data]="tasks" class="marker-paged-grid">
 *     <ng-template #model let-model="model">
 *         <mat-card>
 *             <mat-card-title>
 *                 {{model.id}} Title
 *             </mat-card-title>
 *             <mat-card-content>
 *                 Content for dummy object {{model.id}}
 *             </mat-card-content>
 *         </mat-card>
 *     </ng-template>
 * </ngx-mat-paged-list>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {Task} from './tasks'; // this should extend JsonModel
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * }) UsingBasicUsageExample {
 *     tasks: Task[] = []; // assuming this is initialized with data at some point
 * }
 * ```
 */
export declare class PagedListComponent<T extends JsonModel> extends PagedCollectionComponent<T> {
    static ɵfac: i0.ɵɵFactoryDeclaration<PagedListComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PagedListComponent<any>, "ngx-mat-paged-list", never, {}, {}, never, never>;
}
