/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { ChangeDetectorRef, EventEmitter, OnDestroy } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { JsonModel } from '@ngx-material-dashboard/base-json';
import { Subscription } from 'rxjs';
import { PagedCollectionComponent } from '../../collection/components/paged-collection/paged-collection.component';
import { SearchFilterMap } from '../interfaces/search-filter-map.interface';
import { FilterDropDownComponent } from '../../toolbar/components/filter-drop-down/filter-drop-down.component';
import * as i0 from "@angular/core";
export declare class SearchFilterDirective<T extends JsonModel> implements OnDestroy {
    private changeDetectorRef;
    /** The filter drop down. */
    set filter(val: FilterDropDownComponent);
    /** The form to render in the filter drop down. */
    form: FormGroup;
    /**
     * A reference to the PageCollection that should be included inside the
     * selector for this component.
     */
    collection: PagedCollectionComponent<T>;
    searchClick: EventEmitter<SearchFilterMap>;
    /** The subscriptions in the component. */
    sub: Subscription;
    constructor(changeDetectorRef: ChangeDetectorRef);
    /**
     * Builds a map of search filter data based on controls from given FormGroup,
     * which should be form used in FilterDropDown component defined for the
     * toolbar. The key for each control should match up with expected filter
     * values to be included in query parameters sent to server API. This allows
     * map to be generated dynamically by looping over controls, rather than
     * requiring parent component to define filter map (which can get repetative).
     * Code to loop over form controls taken from answer to stackoverflow below:
     * https://stackoverflow.com/a/42235220/.
     *
     * @param searchFilterData FormGroup defined for filter drop down.
     * @returns A map of search filters to send to server API.
     */
    private buildSearchFilter;
    ngOnDestroy(): void;
    throwError(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SearchFilterDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SearchFilterDirective<any>, "[ngxMatSearchFilter]", never, { "filter": "filter"; "form": "form"; "collection": "collection"; }, { "searchClick": "searchClick"; }, never>;
}
